﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;

namespace SearchWordFromJavaTool
{
    class FileAndFloderTools
    {
        /// <summary>
        /// 获取包含查询内容的集合
        /// </summary>
        /// <param name="path">路径</param>
        /// <param name="searchStr">要查询的内容</param>
        public static List<ContentEntity> GetInfoIncludeSearchStr(string path, string searchStr, string type)
        {
            List<ContentEntity> ceList = new List<ContentEntity>();
            ContentEntity ce;

            //获取查询内容的长度
            int strLength = searchStr.Length;
            //包含路径的所有集合
            List<string> AllFile = GetFileList(path, type, new List<string>(), new List<string>(), true);
            foreach (string item in AllFile)
            {
                FileStream fs = new FileStream(item, FileMode.Open, FileAccess.Read, FileShare.None);
                StreamReader sr = new StreamReader(fs);
                //读取文件的内容
                string strLine = sr.ReadToEnd();
                if (strLine.Length >= strLength)
                {
                    for (int i = 0; i < strLine.Length - strLength; i++)
                    {
                        //判断是否包含查询的内容
                        if (strLine.Substring(i, strLength).Equals(searchStr))
                        {
                            ce = new ContentEntity()
                            {
                                PaOrns = type == FileType.type_Java ? Match.GetPackage(strLine) : Match.GetNamespace(strLine),//判断是哪种类型，选择不同的处理方式
                                FileName = Path.GetFileName(item),
                                UseCount = 1
                            };
                            ceList.Add(ce);
                        }
                    }
                }
                //关闭
                sr.Close();
                fs.Close();
            }
            return ceList;
        }

        /// <summary>
        /// 取得指定路径下所有目录及文件名称（可递归）
        /// </summary>
        /// <param name="strDir">指定路径</param>
        /// <param name="strFilePattern">要与 strDir 中的文件名匹配的搜索字符串
        /// “*.abc*”返回扩展名为 .abc、.abcd、.abcde、.abcdef 等的文件。
        /// “*.abcd”只返回扩展名为 .abcd 的文件。
        ///  “*.abcde”只返回扩展名为 .abcde 的文件。
        /// </param>
        /// <param name="arrDirs">查询得到的所有目录</param>
        /// <param name="arrFiles">查询得到的所有文件名称</param>
        /// <param name="bIsRecursive">是否递归查询</param>
        /// <returns></returns>
        private static List<string> GetFileList(string strDir, string strFilePattern, List<string> arrDirs, List<string> arrFiles, bool bIsRecursive)
        {
            DirectoryInfo dirInfo = new DirectoryInfo(strDir);
            if (string.IsNullOrEmpty(strDir))
                return null;

            try
            {
                //取得指定路径下的所有符合条件的文件
                FileInfo[] strFiles = dirInfo.GetFiles(strFilePattern);
                //取得指定路径下的所有目录
                DirectoryInfo[] strDirs = dirInfo.GetDirectories();

                foreach (FileInfo item in strFiles)
                {//将所有文件名称加入arrFiles中
                    arrFiles.Add(item.FullName);
                }

                foreach (DirectoryInfo item in strDirs)
                {//将所有目录名称加入arrDirs中
                    arrDirs.Add(item.FullName);
                }

                if (bIsRecursive)
                {//递归
                    if (strDirs.Length > 0)
                    {
                        foreach (DirectoryInfo item in strDirs)
                        {//递归遍历所有文件夹
                            GetFileList(item.FullName, strFilePattern, arrDirs, arrFiles, bIsRecursive);
                        }
                    }
                }
            }
            catch (Exception)
            {
                throw;
            }
            return arrFiles;
        }

    }
}
