﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ToolsInterface.Interfaces;

namespace WinTools
{
    /// <summary>
    /// MainWindow.xaml 的交互逻辑
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            LoadWidgets();
        }

        private void LoadWidgets()
        {
            string applicationPath = AppDomain.CurrentDomain.SetupInformation.ApplicationBase;
            string dirPath = applicationPath + "Widgets/";
            if(!Directory.Exists(dirPath))
            {
                MessageBox.Show("未找到相关的Widgets文件夹信息，请确认相关的文件夹是否存在。");
                return;
            }
            DirectoryInfo dir = new DirectoryInfo(dirPath);
            List<DirectoryInfo> lastDirNameList = new List<DirectoryInfo>();
            Tools.FileToolsHelper.GetEndDirectories(dir, lastDirNameList);
            foreach (DirectoryInfo item in lastDirNameList)
            {
                WrapPanel wrapPanel = null;
                TabItem tabItem = Tools.UCToolsHelper.CreateTabByDirName(item.Name,tcToolkClass);
                wrapPanel = Tools.UCToolsHelper.CreateWrapPanel(tabItem);
                string[] dllFilesPath = Directory.GetFiles(item.FullName, "*.dll");
                foreach (string dllPath in dllFilesPath)
                {
                    Assembly assembly = Assembly.LoadFile(dllPath);
                    Type[] types = assembly.GetExportedTypes();
                    foreach (Type type in types)
                    {
                        if(typeof(IToolsInterface).IsAssignableFrom(type)&&!type.IsAbstract)
                        {
                            IToolsInterface toolInterface = Activator.CreateInstance(type) as IToolsInterface;
                            if (toolInterface !=null)
                            {
                                wrapPanel.Children.Add(CreateFunction(toolInterface));
                            }
                        }
                    }
                }
            }
        }

        /// <summary>
        /// 创建功能按钮
        /// </summary>
        /// <param name="toolsInterface"></param>
        /// <returns></returns>
        private UIElement CreateFunction(IToolsInterface toolsInterface)
        {
            Button btn = new Button();
            btn.Click += Btn_Click;
            btn.Content = toolsInterface.ToolName;
            btn.Width = 100;
            btn.Height = 50;
            btn.Margin = new Thickness(5, 0, 0, 0);
            btn.Background = toolsInterface.BackgroundBrush;
            btn.Foreground = toolsInterface.ForgroundBrush;
            btn.Tag = toolsInterface;
            return btn;
        }

        private void Btn_Click(object sender, RoutedEventArgs e)
        {
            Button btn = sender as Button;
            if(btn!=null)
            {
                IToolsInterface toolsInterface = btn.Tag as IToolsInterface;
                if(toolsInterface !=null)
                {
                    FrameworkElement control = toolsInterface.RunToolApplication();

                    gUc.Children.Clear();
                    gUc.Children.Add(control);
                }
                else
                {
                    MessageBox.Show("实例化接口失败");
                }
            }
            else
            {
                MessageBox.Show("实例化按钮失败");
            }
        }

        private void btnExit_Click(object sender, RoutedEventArgs e)
        {

        }
    }
}
