﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows;

namespace WinTools.Tools
{
    class FileToolsHelper
    {
        /// <summary>
        /// 查找指定目录下的所有末级子目录
        /// </summary>
        /// <param name="dir">要查找的目录</param>
        /// <param name="dirList">查找结果列表</param>
        /// <param name="system">是否包含系统目录</param>
        /// <param name="hidden">是否包含隐藏目录</param>
        public static void GetEndDirectories(DirectoryInfo dir,List<DirectoryInfo> dirList,bool system=false,bool hidden=false)
        {
            try
            {
                //返回当前目录的子目录集合
                DirectoryInfo[] dirSub = dir.GetDirectories();
                if(dirSub.Length==0)
                {
                    //如果没有子目录了则添加进列表
                    dirList.Add(dir);
                    return;
                }
                foreach (DirectoryInfo subItem in dirSub)
                {
                    //跳过系统目录
                    if (!system && (subItem.Attributes & FileAttributes.System)==FileAttributes.System)
                    {
                        continue;
                    }
                    //跳过隐藏目录
                    if (!hidden && (subItem.Attributes & FileAttributes.Hidden)==FileAttributes.Hidden)
                    {
                        continue;
                    }
                    //递归
                    GetEndDirectories(subItem, dirList);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("获取目录层级失败。" + ex.Message);
            }
        }
    }
}
